# SL Physics - A

The course code for this page is **SPH3U7**.

## 1.1 - Measurements in physics

!!! reminder
    All physical quantities must be expressed as a **product** of a magnitude and a unit. For example, ten metres should be written as $10 \text{ m}$.

### Fundamental units

Every other SI unit is derived from the fundamental SI units. Memorise these!

| Quantity type | Unit | Symbol |
| --- | --- | --- |
| Time | Second | s |
| Distance | Metre | m |
| Mass | Kilogram | kg |
| Electric current | Ampere | A |
| Temperature | Kelvin | K |
| Amount of substance | Mole | mol |
| Luminous intensity | Candela | cd |

### Metric prefixes

Every SI unit can be expanded with metric prefixes. Note that the difference between many of these prefixes is $10^3$.

!!! example
    milli + metre = millimetre ($10^{-3}$) m

| Prefix | Abbreviation | Value | Inverse ($10^{-n}$) abbreviation | Inverse prefix |
| --- | --- | --- | --- | --- |
| deca- | da | $10^1$ | d | deci- |
| hecto- | h | $10^2$ | c | centi- |
| kilo- | k | $10^3$ | m | milli- |
| mega- | M | $10^6$ | µ | micro- |
| giga- | G | $10^9$ | n | nano- |
| tera- | T | $10^{12}$ | p | pico- |
| peta- | P | $10^{15}$ | f | femto- |
| exa- | E | $10^{18}$ | a | atto- |

### Significant figures

 - The leftmost non-zero digit is the **most significant digit**.
 - If there is no decimal point, the rightmost non-zero digit is the **least significant digit**.
	- Otherwise, the right-most digit (including zeroes) is the least significant digit.
 - All digits between the most and least significant digits are significant.
 - Pure (discrete) numbers are unitless and have infinite significant figures.

!!! example
    In $123000$, there are 3 significant digits.<br>
    In $0.1230$, there are 4 significant digits.

 - When adding or subtracting significant figures, the answer has the **same number of decimals** as the number with the lowest number of decimal points.
 - When multiplying or dividing significant figures, the answer has the **same number of significant figures** as the number with the lowest number of significant figures.
 - Values of a calculated result can be **no more precise** than the least precise value used.

!!! example
    $$1.25 + 1.20 = 2.45$$
    $$1.24 + 1.2 = 2.4$$
    $$1.2 × 2 = 2$$
    $$1.2 × 2.0 = 2.4$$

!!! warning
    When rounding an answer with significant figures, if the **least significant figure** is $5$, round up only if the **second-least** significant figure is **odd**.

    $$1.25 + 1.2 = 2.4$$
    $$1.35 + 1.2 = 2.6$$

### Scientific notation

Scientific notation is written in the form of $m×10^{n}$, where $1 \leq m < 10, n \in \mathbb{Z}$. All digits before the multiplication sign in scientific notation are significant.<br>

!!! example
    The speed of light is 300 000 000 ms<sup>-1</sup>, or $3×10^8$ ms<sup>-1</sup>.

### Orders of magnitude

The order of magnitude of a number can be found by converting it to scientific notation and taking its power of 10.

!!! example
    - The order of magnitude of $212000$, or $2.12×10^{5}$, is 5.
    - The order of magnitude of $0.212$, or $2.12×10^{-1}$, is -1.

## 1.2 - Uncertainties and errors

### Random and systematic errors

| Random error | Systematic error |
| --- | --- |
| Caused by imperfect measurements and is present in every measurement. | Caused by a flaw in experiment design or in the procedure. |
| Can be reduced (but not avoided) by repeated trials or measurements. | Cannot be reduced by repeated measurements, but can be avoided completely. |
| Error in precision. | Error in accuracy. |

!!! example
    - The failure to account for fluid evaporating at high temperatures is a systematic error, as it cannot be minimised by repeated measurements.
    - The addition of slightly more solute due to uncertainty in instrument data is a random error, as it can be reduced by averaging the result of multiple trials.

<img src="/resources/images/types-of-error.png" width=700>(Source: Kognity)</img>

### Uncertainties

Uncertainties are stated in the form of $a±\Delta a$. A value is only as precise as its absolute uncertainty. Absolute uncertainty of a **measurement** is usually represented to only 1 significant digit.

 - The absolute uncertainty of a number is written in the same unit as the value.
 - The percentage uncertainty of a number is the written as a percentage of the value.

!!! example
    - Absolute uncertainty: 1.0 g ± 0.1 g
    - Percentage uncertainty: 1.0 g ± 10%

To determine a measurement's absolute uncertainty, if:

 - the instrument states its uncertainty, use that.
 - an analog instrument is used, half of the most precise reading is uncertain.
 - a digital instrument is used, the last reported digit is uncertain by 1 at its order of magnitude.

!!! example
    - A ruler has millimetre markings. A pencil placed alongside the ruler has its tip just past 14 mm but before 15 mm. The pencil is 14.5 mm ± 0.5 mm long.
    - A digital scale reads 0.66 kg for the mass of a human body. The human body has a mass of 0.66 kg ± 0.01 kg.

See [Dealing with Uncertainties](/resources/g11/physics-uncertainties.pdf) for how to perform **operations with uncertainties**.

### Error bars

Error bars represent the uncertainty of the data, typically representing that data point's standard deviation, and can be both horizontal or vertical. A data point with uncertain values is written as $(x ± \Delta x, y ± \Delta y)$

<img src="/resources/images/error-bars.png" width=600>(Source: Kognity)</img>

### Uncertainty of gradient and intercepts

!!! note "Definition"
    - The **line of best fit** is the line that passes through **as many error bars as possible** while passing as closely as possible to all data points.
    - The **minimum and maximum lines** are lines that minimise/maximise their slopes while passing through the first and last **error bars**.

!!! warning
    - Use solid lines for lines representing **continuous data** and dotted lines for **discrete data**.

<img src="/resources/images/error-slopes.png" width=700>(Source: Kognity)</img>

The uncertainty of the **slope** of the line of best fit is the difference between the maximum and minimum slopes.
$$m_{\text{best fit}} ± \frac{m_{\max}-m_{\min}}{2}$$
The uncertainty of the **intercepts** is the difference between the intercepts of the maximum and minimum lines.
$$\text{intercept}_{\text{best fit}} ± \frac{\text{intercept}_{\max} - \text{intercept}_{\min}}{2}$$


## 1.3 - Vectors and scalars

!!! note "Definition"
    - **Scalar:** A physical quantity with a numerical value (magnitude) and a unit.
    - **Vector:** A physical quantity with a **non-negative** numerical value (magnitude), a unit, and a **direction.**

??? example
    - Scalar quantities include speed, distance, mass, temperature, pressure, time, frequency, current, voltage, and more.
    - Vector quantities include velocity, displacement, acceleration, force (e.g., weight), momentum, impulse, and more.

Vectors are drawn as arrows whose length represents their scale/magnitude and their orientation refer to their direction. A variable representing a vector is written with a right-pointing arrow above it.

 - The **standard form** of a vector is expressed as its magnitude followed by its unit followed by its direction in square brackets.
$$\vec{a} = 1\text{ m }[N 45° E]$$
 - The **component form** of a vector is expressed as the location of its head on a cartesian plane if its tail were at $(0, 0)$.
$$\vec{a} = (1, 1)$$
 - The **magnitude** of a vector can be expressed as the absolute value of a vector.
$$|\vec{a}| = 1 \text{ m}$$

### Adding/subtracting vectors diagrammatically

1. Draw the first vector.
2. Draw the second vector with its tail at the head of the first vector.
3. Repeat step 2 as necessary for as many vectors as you want by attaching them to the *head* of the last vector.
4. Draw a new ("resultant") vector from the tail of the first vector to the head of the last vector.

<img src="/resources/images/vector-add-direction.png" width=700>(Source: Kognity)</img>

When subtracting exactly one vector from another, repeat the steps above, but instead place the second vector at the **tail** of the first, then draw the resultant vector from the head of the second vector to the head of the first vector. Note that this only applies when subtracting exactly one vector from another.

!!! example
    In the diagram above, $\vec{b}=\vec{a+b}-\vec{a}$.

Alternatively, for any number of vectors, negate the vector(s) being subtracted by **giving it an opposite direction** and then add the negative vectors.

<img src="/resources/images/vector-subtract-direction.png" width=700>(Source: Kognity)</img>

### Adding/subtracting vectors algebraically

Vectors can be broken up into two **component vectors** laying on the x- and y-axes via trigonometry such that the resultant of the two components is the original vector. This is especially helpful when adding larger (3+) numbers of vectors.
$$\vec{F}_x + \vec{F}_y = \vec{F}$$

!!! info "Reminder"
    The **component form** of a vector is expressed as $(|\vec{a}_x|, |\vec{a}_y|)$

<img src="/resources/images/vector-simple-adding.png" width=700>(Source: Kognity)</img>

By using the primary trignometric identities:
$$
|\vec{a}_{x}| = |\vec{a}|\cos\theta_{a} \\
|\vec{a}_{y}| = |\vec{a}|\sin\theta_{a}
$$

<img src="/resources/images/vector-decomposition.png" width=700>(Source: Kognity)</img>

Using their component forms, to:

 - add two vectors, add their x- and y-coordinates together.
 - subtract two vectors, subtract their x- and y-coordinates together.

$$
(a_{x}, a_{y}) + (b_{x}, b_{y}) = (a_{x} + b_{x}, a_{y} + b_{y}) \\
(a_{x}, a_{y}) - (b_{x}, b_{y}) = (a_{x} - b_{x}, a_{y} - b_{y})
$$

The length of resultant vector can then be found using the Pythagorean theorem.

$$
|\vec{c}|=\sqrt{c_{x}^2 + c_{y}^2}
$$

To find the resultant direction, use inverse tan to calculate the angle of the vector using the lengths of its components.

$$
\theta_{c} = \tan^{-1}(\frac{c_y}{c_x})
$$

### Multiplying vectors and scalars

The product of a vector multiplied by a scalar is a vector with a magnitude of the vector multiplied by the scalar with the same direction as the original vector.

$$\vec{v} × s = (|\vec{v}|×s)[\theta_{v}]$$

!!! example
    $$3 \text{ m} · 47 \text{ ms}^{-1}[N20°E] = 141 \text{ ms}^{-1}[N20°E]$$

## 2.1 - Motion

### Models

A **scientific model** is a simplification of a system based on assumptions used to explain or make predictions for that system.

!!! note "Definition"
    - **System**: An object or a connected group of objects.
    - **Point particle assumption**: An assumption that models a system as a blob of matter. It is more reliable if the size and shape of the object(s) do not matter much.
    - **Uniform motion**: The type of motion in which the speed of an object is constant.

### Displaying motion

Motion can be expressed visually using a **motion diagram** or a **position-time graph**.

// TODO: insert motion diagram here because kognity bad

A **position-time graph** expands on the motion diagram by specifying a precise **position** value on the vertical axis in addition to time on the horizontal axis. The line of best fit indicates the object's speed, as well as if it is accelerating or decelerating.

<img src="/resources/images/position-time-graph.png" width=700>(Source: Kognity)</img>

When the slope is:

 - linear, the object is moving at a constant speed.
 - exponential, the object is accelerating.
 - logarithmic, the object is decelerating.

## 2.2 - Forces

## 2.3 - Work, energy, and power

## 2.4 - Momentum and impulse

## 3.1 - Thermal concepts

## 3.2 - Modelling a gas

## Resources

 - [IB Physics Data Booklet](/resources/g11/ib-physics-data-booklet.pdf)
 - [IB SL Physics Syllabus](/resources/g11/ib-physics-syllabus.pdf)
 - [Dealing with Uncertainties](/resources/g11/physics-uncertainties.pdf)
 - [Linearising Data](/resources/g11/linearising-data.pdf)
 - [External: IB Physics Notes](https://ibphysics.org)
